@@ -216,7 +216,7 @@ class ClassProcessor(list):
 	def read(self, aType=0):
 		finalStr = ""
 		if aType == 0:
-			for item in self[0][0]:
+			for item in self.dataRaw:
 				try:
 					item = str(item) + "%, "
 					finalStr = finalStr + item
@@ -224,7 +224,7 @@ class ClassProcessor(list):
 					print("error : UNABLE TO PROCESS DATA TO READ")
 					return
 		elif aType == 1:
-			data = self[0][1]
+			data = self.dataStats
 			try:
 				finalStr = "average=" + str(data["average"]) + ",\nminimum=" + str(data["minimum"]) + ",\nmaximum=" + str(data["maximum"])
 			except:
